@@ -35,6 +35,11 @@ def query_yes_no(question, default="yes"):
             sys.stdout.write("Please respond with 'yes' or 'no' "\
                              "(or 'y' or 'n').\n")
 
+class MySQLRocketDB:
+	name = ""
+	size = ""
+	tables_number = ""
+	rows_number = ""
 
 class MySQLRocket:
 	name = "default"
@@ -110,6 +115,11 @@ class MySQLRocket:
 					print 'WARNING: password has been stored in plain text \n'
 
 	def mk(self, db_name, db_password):
+		db_list=self.showdb('%')
+		for database in db_list:
+			if database==db_name:
+				print 'Error database already exist!'
+				sys.exit(1)
 		db_user=db_name
 		dictionnary=string.ascii_letters+string.digits # alphanumeric, upper and lowercase
 		if db_password=='':
@@ -138,12 +148,14 @@ class MySQLRocket:
 
 	def ls(self, db_pattern='%'):
 		db_list=self.showdb(db_pattern)
-		print '##################################'
-		print '#        Database list           #'
-		print '##################################'
+		print "-"*80
+		print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format("Database", "Tables number", "Rows number", "Size (MB)")
+		print "-"*80
+		db_list.sort()
 		for database in db_list:
-			print '  '+database
-		print '##################################'		
+			db=self.get_db_properties(database)
+			print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format(db.name[:20], db.tables_number [:20], db.rows_number[:8], db.size[:30])
+		print "-"*80	
 
 	def showdb(self, db_pattern='%'):
 		db_list=[]
@@ -224,14 +236,36 @@ class MySQLRocket:
 			print('Error %d: %s' % (e.args[0], e.args[1]))
 			sys.exit(1)
 
+	def get_db_properties(self, db_name):
+		db=MySQLRocketDB()
+		db.name=db_name
+		try:
+			conn = mysql.connect(host=self.host, port=self.port, user=self.user, passwd=self.password)
+			cursor = conn.cursor()
+			cursor.execute('SELECT count(*) FROM information_schema.tables WHERE TABLE_SCHEMA="{database_name}";'.format(database_name=db.name))
+			result=cursor.fetchone()
+			db.tables_number=str(result[0])
+			cursor.execute('SELECT SUM(TABLE_ROWS) FROM information_schema.tables WHERE TABLE_SCHEMA="{database_name}";'.format(database_name=db.name))
+			result=cursor.fetchone()
+			db.rows_number=str(result[0])
+			cursor.execute('SELECT ROUND(SUM( data_length + index_length ) / 1024 / 1024, 3) FROM information_schema.tables WHERE TABLE_SCHEMA="{database_name}";'.format(database_name=db.name))
+			result=cursor.fetchone()
+			db.size=str(result[0])
+			cursor.close()
+			conn.close()
+		except mysql.Error, e:	
+			print('Error %d: %s' % (e.args[0], e.args[1]))
+			sys.exit(1)
+		return db
+
 def launcher():
 	parser = ArgumentParser(description=ressources.__description__,prog="mysqlrocket")
 
 	parser.add_argument("-v", "--version",  action="version",   version="%(prog)s : "+ressources.__version__ ,help="Show program version.")
-	parser.add_argument('-u', type=str, default='root', help='mysql user')
-	parser.add_argument('-H', type=str, default='localhost', help='mysql host')
-	parser.add_argument('-p', type=str, default='', help='mysql password')
-
+	parser.add_argument('-u', dest='mysql_user', metavar='<mysql_user>', type=str, help='mysql user')
+	parser.add_argument('-H', dest='mysql_host', metavar='<mysql_host>', type=str, help='mysql host')
+	parser.add_argument('-p', dest='mysql_password', metavar='<mysql_password>', type=str, help='mysql password')
+	parser.add_argument('-P', dest='mysql_port', metavar='<mysql_user>', type=int, help='mysql port')
 
 	subparsers = parser.add_subparsers(help='Avalaible commands')
 
@@ -240,16 +274,16 @@ def launcher():
 
 	parser_mk = subparsers.add_parser('mk',description='Create a MySQL database', help='Create a MySQL database')
 	parser_mk.add_argument('mk_db_name', metavar='<db_name>', type=str, help='Name of the created database')
-	parser_mk.add_argument('-f', '--force-password',dest='mk_db_pass', type=str, default='', help='Override random password generation')
+	parser_mk.add_argument('-f', '--force-password',dest='mk_db_pass', metavar='<new_user_password>', type=str, default='', help='Override random password generation')
 
 	parser_ls = subparsers.add_parser('ls', description='Show databases on MySQL server', help='Show databases on MySQL server')
 	parser_ls.add_argument('ls_db_pattern', metavar='<search_pattern>', type=str, nargs='?', default='%', help='Show only databases name matching pattern')
 
 	parser_rm = subparsers.add_parser('rm',description='Delete a MySQL database', help='Delete a MySQL database')
-	parser_rm.add_argument('rm_db_name', type=str, help='Name of the deleted database')
+	parser_rm.add_argument('rm_db_name', metavar='<db_name>', type=str, help='Name of the deleted database')
 
 	parser_dp = subparsers.add_parser('dp',description='Dump a MySQL database', help='Dump a MySQL database')
-	parser_dp.add_argument('dp_db_name', type=str, help='Name of the dumped database')
+	parser_dp.add_argument('dp_db_name', metavar='<db_name>', type=str, help='Name of the dumped database')
 
 	parser_bk = subparsers.add_parser('bk', description='Backup all databases on MySQL server', help='Backup all databases on MySQL server')
 	parser_bk.add_argument('bk_db_pattern', metavar='<backup_pattern>', type=str, nargs='?', default='%', help='Dump only databases name matching pattern')
@@ -259,6 +293,14 @@ def launcher():
 
 	args = parser.parse_args() 
 
+	if args.mysql_user is not None: session.user = args.mysql_user
+
+	if args.mysql_host is not None: session.host = args.mysql_host
+
+	if args.mysql_password is not None: session.password = args.mysql_password
+
+	if args.mysql_port is not None: session.port = args.mysql_port
+
 	if hasattr(args,'mk_db_name'): 
 	    session.mk(args.mk_db_name,args.mk_db_pass)
 
